<?php

return [
    'Names' => [
        'af' => 'আফ্ৰিকানছ্',
        'af_NA' => 'আফ্ৰিকানছ্ (নামিবিয়া)',
        'af_ZA' => 'আফ্ৰিকানছ্ (দক্ষিণ আফ্রিকা)',
        'ak' => 'আকান',
        'ak_GH' => 'আকান (ঘানা)',
        'am' => 'আমহাৰিক',
        'am_ET' => 'আমহাৰিক (ইথিঅ’পিয়া)',
        'ar' => 'আৰবী',
        'ar_001' => 'আৰবী (বিশ্ব)',
        'ar_AE' => 'আৰবী (সংযুক্ত আৰব আমিৰাত)',
        'ar_BH' => 'আৰবী (বাহৰেইন)',
        'ar_DJ' => 'আৰবী (জিবুটি)',
        'ar_DZ' => 'আৰবী (আলজেৰিয়া)',
        'ar_EG' => 'আৰবী (ইজিপ্ত)',
        'ar_EH' => 'আৰবী (পশ্চিমীয় ছাহাৰা)',
        'ar_ER' => 'আৰবী (এৰিত্ৰিয়া)',
        'ar_IL' => 'আৰবী (ইজৰাইল)',
        'ar_IQ' => 'আৰবী (ইৰাক)',
        'ar_JO' => 'আৰবী (জৰ্ডান)',
        'ar_KM' => 'আৰবী (কোমোৰোজ)',
        'ar_KW' => 'আৰবী (কুৱেইট)',
        'ar_LB' => 'আৰবী (লেবানন)',
        'ar_LY' => 'আৰবী (লিবিয়া)',
        'ar_MA' => 'আৰবী (মৰক্কো)',
        'ar_MR' => 'আৰবী (মাউৰিটানিয়া)',
        'ar_OM' => 'আৰবী (ওমান)',
        'ar_PS' => 'আৰবী (ফিলিস্তিন অঞ্চল)',
        'ar_QA' => 'আৰবী (কাটাৰ)',
        'ar_SA' => 'আৰবী (চৌডি আৰবিয়া)',
        'ar_SD' => 'আৰবী (চুডান)',
        'ar_SO' => 'আৰবী (চোমালিয়া)',
        'ar_SS' => 'আৰবী (দক্ষিণ চুডান)',
        'ar_SY' => 'আৰবী (চিৰিয়া)',
        'ar_TD' => 'আৰবী (চাড)',
        'ar_TN' => 'আৰবী (টুনিচিয়া)',
        'ar_YE' => 'আৰবী (য়েমেন)',
        'as' => 'অসমীয়া',
        'as_IN' => 'অসমীয়া (ভাৰত)',
        'az' => 'আজেৰবাইজানী',
        'az_AZ' => 'আজেৰবাইজানী (আজাৰবেইজান)',
        'az_Cyrl' => 'আজেৰবাইজানী (চিৰিলিক)',
        'az_Cyrl_AZ' => 'আজেৰবাইজানী (চিৰিলিক, আজাৰবেইজান)',
        'az_Latn' => 'আজেৰবাইজানী (লেটিন)',
        'az_Latn_AZ' => 'আজেৰবাইজানী (লেটিন, আজাৰবেইজান)',
        'be' => 'বেলাৰুছীয়',
        'be_BY' => 'বেলাৰুছীয় (বেলাৰুছ)',
        'bg' => 'বুলগেৰীয়',
        'bg_BG' => 'বুলগেৰীয় (বুলগেৰিয়া)',
        'bm' => 'বামবাৰা',
        'bm_ML' => 'বামবাৰা (মালি)',
        'bn' => 'বাংলা',
        'bn_BD' => 'বাংলা (বাংলাদেশ)',
        'bn_IN' => 'বাংলা (ভাৰত)',
        'bo' => 'তিব্বতী',
        'bo_CN' => 'তিব্বতী (চীন)',
        'bo_IN' => 'তিব্বতী (ভাৰত)',
        'br' => 'ব্ৰেটন',
        'br_FR' => 'ব্ৰেটন (ফ্ৰান্স)',
        'bs' => 'বছনীয়',
        'bs_BA' => 'বছনীয় (ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'bs_Cyrl' => 'বছনীয় (চিৰিলিক)',
        'bs_Cyrl_BA' => 'বছনীয় (চিৰিলিক, ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'bs_Latn' => 'বছনীয় (লেটিন)',
        'bs_Latn_BA' => 'বছনীয় (লেটিন, ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'ca' => 'কাতালান',
        'ca_AD' => 'কাতালান (আন্দোৰা)',
        'ca_ES' => 'কাতালান (স্পেইন)',
        'ca_FR' => 'কাতালান (ফ্ৰান্স)',
        'ca_IT' => 'কাতালান (ইটালি)',
        'ce' => 'চেচেন',
        'ce_RU' => 'চেচেন (ৰাছিয়া)',
        'cs' => 'চেক',
        'cs_CZ' => 'চেক (চিজেচিয়া)',
        'cv' => 'চুভাচ',
        'cv_RU' => 'চুভাচ (ৰাছিয়া)',
        'cy' => 'ৱেলচ',
        'cy_GB' => 'ৱেলচ (সংযুক্ত ৰাজ্য)',
        'da' => 'ডেনিচ',
        'da_DK' => 'ডেনিচ (ডেনমাৰ্ক)',
        'da_GL' => 'ডেনিচ (গ্ৰীণলেণ্ড)',
        'de' => 'জাৰ্মান',
        'de_AT' => 'জাৰ্মান (অষ্ট্ৰিয়া)',
        'de_BE' => 'জাৰ্মান (বেলজিয়াম)',
        'de_CH' => 'জাৰ্মান (চুইজাৰলেণ্ড)',
        'de_DE' => 'জাৰ্মান (জাৰ্মানী)',
        'de_IT' => 'জাৰ্মান (ইটালি)',
        'de_LI' => 'জাৰ্মান (লিচটেনষ্টেইন)',
        'de_LU' => 'জাৰ্মান (লাক্সেমবাৰ্গ)',
        'dz' => 'জোংখা',
        'dz_BT' => 'জোংখা (ভুটান)',
        'ee' => 'ইৱে',
        'ee_GH' => 'ইৱে (ঘানা)',
        'ee_TG' => 'ইৱে (টোগো)',
        'el' => 'গ্ৰীক',
        'el_CY' => 'গ্ৰীক (চাইপ্ৰাছ)',
        'el_GR' => 'গ্ৰীক (গ্ৰীচ)',
        'en' => 'ইংৰাজী',
        'en_001' => 'ইংৰাজী (বিশ্ব)',
        'en_150' => 'ইংৰাজী (ইউৰোপ)',
        'en_AE' => 'ইংৰাজী (সংযুক্ত আৰব আমিৰাত)',
        'en_AG' => 'ইংৰাজী (এণ্টিগুৱা আৰু বাৰ্বুডা)',
        'en_AI' => 'ইংৰাজী (এনগুইলা)',
        'en_AS' => 'ইংৰাজী (আমেৰিকান চামোৱা)',
        'en_AT' => 'ইংৰাজী (অষ্ট্ৰিয়া)',
        'en_AU' => 'ইংৰাজী (অষ্ট্ৰেলিয়া)',
        'en_BB' => 'ইংৰাজী (বাৰ্বাডোচ)',
        'en_BE' => 'ইংৰাজী (বেলজিয়াম)',
        'en_BI' => 'ইংৰাজী (বুৰুণ্ডি)',
        'en_BM' => 'ইংৰাজী (বাৰ্মুডা)',
        'en_BS' => 'ইংৰাজী (বাহামাছ)',
        'en_BW' => 'ইংৰাজী (ব’টচোৱানা)',
        'en_BZ' => 'ইংৰাজী (বেলিজ)',
        'en_CA' => 'ইংৰাজী (কানাডা)',
        'en_CC' => 'ইংৰাজী (কোকোচ [কীলিং] দ্বীপপুঞ্জ)',
        'en_CH' => 'ইংৰাজী (চুইজাৰলেণ্ড)',
        'en_CK' => 'ইংৰাজী (কুক দ্বীপপুঞ্জ)',
        'en_CM' => 'ইংৰাজী (কেমেৰুণ)',
        'en_CX' => 'ইংৰাজী (খ্ৰীষ্টমাছ দ্বীপ)',
        'en_CY' => 'ইংৰাজী (চাইপ্ৰাছ)',
        'en_DE' => 'ইংৰাজী (জাৰ্মানী)',
        'en_DK' => 'ইংৰাজী (ডেনমাৰ্ক)',
        'en_DM' => 'ইংৰাজী (ড’মিনিকা)',
        'en_ER' => 'ইংৰাজী (এৰিত্ৰিয়া)',
        'en_FI' => 'ইংৰাজী (ফিনলেণ্ড)',
        'en_FJ' => 'ইংৰাজী (ফিজি)',
        'en_FK' => 'ইংৰাজী (ফকলেণ্ড দ্বীপপুঞ্জ)',
        'en_FM' => 'ইংৰাজী (মাইক্ৰোনেচিয়া)',
        'en_GB' => 'ইংৰাজী (সংযুক্ত ৰাজ্য)',
        'en_GD' => 'ইংৰাজী (গ্ৰেনাডা)',
        'en_GG' => 'ইংৰাজী (গোৰেনচি)',
        'en_GH' => 'ইংৰাজী (ঘানা)',
        'en_GI' => 'ইংৰাজী (জিব্ৰাল্টৰ)',
        'en_GM' => 'ইংৰাজী (গাম্বিয়া)',
        'en_GU' => 'ইংৰাজী (গুৱাম)',
        'en_GY' => 'ইংৰাজী (গায়ানা)',
        'en_HK' => 'ইংৰাজী (হং কং এছ. এ. আৰ. চীন)',
        'en_IE' => 'ইংৰাজী (আয়াৰলেণ্ড)',
        'en_IL' => 'ইংৰাজী (ইজৰাইল)',
        'en_IM' => 'ইংৰাজী (আইল অফ মেন)',
        'en_IN' => 'ইংৰাজী (ভাৰত)',
        'en_IO' => 'ইংৰাজী (ব্ৰিটিছ ইণ্ডিয়ান অ’চন টেৰিট’ৰি)',
        'en_JE' => 'ইংৰাজী (জাৰ্চি)',
        'en_JM' => 'ইংৰাজী (জামাইকা)',
        'en_KE' => 'ইংৰাজী (কেনিয়া)',
        'en_KI' => 'ইংৰাজী (কিৰিবাটি)',
        'en_KN' => 'ইংৰাজী (ছেইণ্ট কিটছ আৰু নেভিছ)',
        'en_KY' => 'ইংৰাজী (কেইমেন দ্বীপপুঞ্জ)',
        'en_LC' => 'ইংৰাজী (ছেইণ্ট লুচিয়া)',
        'en_LR' => 'ইংৰাজী (লিবেৰিয়া)',
        'en_LS' => 'ইংৰাজী (লেছ’থ’)',
        'en_MG' => 'ইংৰাজী (মাদাগাস্কাৰ)',
        'en_MH' => 'ইংৰাজী (মাৰ্শ্বাল দ্বীপপুঞ্জ)',
        'en_MO' => 'ইংৰাজী (মাকাও এছ. এ. আৰ. চীন)',
        'en_MP' => 'ইংৰাজী (উত্তৰ মাৰিয়ানা দ্বীপপুঞ্জ)',
        'en_MS' => 'ইংৰাজী (ম’ণ্টছেৰাট)',
        'en_MT' => 'ইংৰাজী (মাল্টা)',
        'en_MU' => 'ইংৰাজী (মৰিছাছ)',
        'en_MV' => 'ইংৰাজী (মালদ্বীপ)',
        'en_MW' => 'ইংৰাজী (মালাৱি)',
        'en_MY' => 'ইংৰাজী (মালয়েচিয়া)',
        'en_NA' => 'ইংৰাজী (নামিবিয়া)',
        'en_NF' => 'ইংৰাজী (ন’ৰফ’ক দ্বীপ)',
        'en_NG' => 'ইংৰাজী (নাইজেৰিয়া)',
        'en_NL' => 'ইংৰাজী (নেডাৰলেণ্ড)',
        'en_NR' => 'ইংৰাজী (নাউৰু)',
        'en_NU' => 'ইংৰাজী (নিউ)',
        'en_NZ' => 'ইংৰাজী (নিউজিলেণ্ড)',
        'en_PG' => 'ইংৰাজী (পাপুৱা নিউ গিনি)',
        'en_PH' => 'ইংৰাজী (ফিলিপাইনছ)',
        'en_PK' => 'ইংৰাজী (পাকিস্তান)',
        'en_PN' => 'ইংৰাজী (পিটকেইৰ্ণ দ্বীপপুঞ্জ)',
        'en_PR' => 'ইংৰাজী (পুৱেৰ্টো ৰিকো)',
        'en_PW' => 'ইংৰাজী (পালাউ)',
        'en_RW' => 'ইংৰাজী (ৰোৱাণ্ডা)',
        'en_SB' => 'ইংৰাজী (চোলোমোন দ্বীপপুঞ্জ)',
        'en_SC' => 'ইংৰাজী (ছিচিলিছ)',
        'en_SD' => 'ইংৰাজী (চুডান)',
        'en_SE' => 'ইংৰাজী (চুইডেন)',
        'en_SG' => 'ইংৰাজী (ছিংগাপুৰ)',
        'en_SH' => 'ইংৰাজী (ছেইণ্ট হেলেনা)',
        'en_SI' => 'ইংৰাজী (শ্লোভেনিয়া)',
        'en_SL' => 'ইংৰাজী (চিয়েৰা লিঅ’ন)',
        'en_SS' => 'ইংৰাজী (দক্ষিণ চুডান)',
        'en_SX' => 'ইংৰাজী (চিণ্ট মাৰ্টেন)',
        'en_SZ' => 'ইংৰাজী (ইচ্চুটিনি)',
        'en_TC' => 'ইংৰাজী (টাৰ্কছ অৰু কেইক’ছ দ্বীপপুঞ্জ)',
        'en_TK' => 'ইংৰাজী (টোকেলাউ)',
        'en_TO' => 'ইংৰাজী (টংগা)',
        'en_TT' => 'ইংৰাজী (ট্ৰিনিডাড আৰু টোবাগো)',
        'en_TV' => 'ইংৰাজী (টুভালু)',
        'en_TZ' => 'ইংৰাজী (তাঞ্জানিয়া)',
        'en_UG' => 'ইংৰাজী (উগাণ্ডা)',
        'en_UM' => 'ইংৰাজী (ইউ. এছ. আউটলায়িং দ্বীপপুঞ্জ)',
        'en_US' => 'ইংৰাজী (মাৰ্কিন যুক্তৰাষ্ট্ৰ)',
        'en_VC' => 'ইংৰাজী (ছেইণ্ট ভিনচেণ্ট আৰু গ্ৰীণাডাইনছ)',
        'en_VG' => 'ইংৰাজী (ব্ৰিটিছ ভাৰ্জিন দ্বীপপুঞ্জ)',
        'en_VI' => 'ইংৰাজী (ইউ. এছ. ভাৰ্জিন দ্বীপপুঞ্জ)',
        'en_VU' => 'ইংৰাজী (ভানাটু)',
        'en_WS' => 'ইংৰাজী (চামোৱা)',
        'en_ZA' => 'ইংৰাজী (দক্ষিণ আফ্রিকা)',
        'en_ZM' => 'ইংৰাজী (জাম্বিয়া)',
        'en_ZW' => 'ইংৰাজী (জিম্বাবৱে)',
        'eo' => 'এস্পেৰান্তো',
        'eo_001' => 'এস্পেৰান্তো (বিশ্ব)',
        'es' => 'স্পেনিচ',
        'es_419' => 'স্পেনিচ (লেটিন আমেৰিকা)',
        'es_AR' => 'স্পেনিচ (আৰ্জেণ্টিনা)',
        'es_BO' => 'স্পেনিচ (বলিভিয়া)',
        'es_BR' => 'স্পেনিচ (ব্ৰাজিল)',
        'es_BZ' => 'স্পেনিচ (বেলিজ)',
        'es_CL' => 'স্পেনিচ (চিলি)',
        'es_CO' => 'স্পেনিচ (কলম্বিয়া)',
        'es_CR' => 'স্পেনিচ (কোষ্টা ৰিকা)',
        'es_CU' => 'স্পেনিচ (কিউবা)',
        'es_DO' => 'স্পেনিচ (ড’মিনিকান ৰিপাব্লিক)',
        'es_EC' => 'স্পেনিচ (ইকুৱেডৰ)',
        'es_ES' => 'স্পেনিচ (স্পেইন)',
        'es_GQ' => 'স্পেনিচ (ইকুৱেটৰিয়েল গিনি)',
        'es_GT' => 'স্পেনিচ (গুৱাটেমালা)',
        'es_HN' => 'স্পেনিচ (হন্দুৰাছ)',
        'es_MX' => 'স্পেনিচ (মেক্সিকো)',
        'es_NI' => 'স্পেনিচ (নিকাৰাগুৱা)',
        'es_PA' => 'স্পেনিচ (পানামা)',
        'es_PE' => 'স্পেনিচ (পেৰু)',
        'es_PH' => 'স্পেনিচ (ফিলিপাইনছ)',
        'es_PR' => 'স্পেনিচ (পুৱেৰ্টো ৰিকো)',
        'es_PY' => 'স্পেনিচ (পাৰাগুৱে)',
        'es_SV' => 'স্পেনিচ (এল ছেলভেড’ৰ)',
        'es_US' => 'স্পেনিচ (মাৰ্কিন যুক্তৰাষ্ট্ৰ)',
        'es_UY' => 'স্পেনিচ (উৰুগুৱে)',
        'es_VE' => 'স্পেনিচ (ভেনিজুৱেলা)',
        'et' => 'এষ্টোনিয়',
        'et_EE' => 'এষ্টোনিয় (ইষ্টোনিয়া)',
        'eu' => 'বাস্ক',
        'eu_ES' => 'বাস্ক (স্পেইন)',
        'fa' => 'ফাৰ্ছী',
        'fa_AF' => 'ফাৰ্ছী (আফগানিস্তান)',
        'fa_IR' => 'ফাৰ্ছী (ইৰান)',
        'ff' => 'ফুলাহ',
        'ff_Adlm' => 'ফুলাহ (এডলাম)',
        'ff_Adlm_BF' => 'ফুলাহ (এডলাম, বুৰকিনা ফাচো)',
        'ff_Adlm_CM' => 'ফুলাহ (এডলাম, কেমেৰুণ)',
        'ff_Adlm_GH' => 'ফুলাহ (এডলাম, ঘানা)',
        'ff_Adlm_GM' => 'ফুলাহ (এডলাম, গাম্বিয়া)',
        'ff_Adlm_GN' => 'ফুলাহ (এডলাম, গিনি)',
        'ff_Adlm_GW' => 'ফুলাহ (এডলাম, গিনি-বিছাও)',
        'ff_Adlm_LR' => 'ফুলাহ (এডলাম, লিবেৰিয়া)',
        'ff_Adlm_MR' => 'ফুলাহ (এডলাম, মাউৰিটানিয়া)',
        'ff_Adlm_NE' => 'ফুলাহ (এডলাম, নাইজাৰ)',
        'ff_Adlm_NG' => 'ফুলাহ (এডলাম, নাইজেৰিয়া)',
        'ff_Adlm_SL' => 'ফুলাহ (এডলাম, চিয়েৰা লিঅ’ন)',
        'ff_Adlm_SN' => 'ফুলাহ (এডলাম, চেনেগাল)',
        'ff_CM' => 'ফুলাহ (কেমেৰুণ)',
        'ff_GN' => 'ফুলাহ (গিনি)',
        'ff_Latn' => 'ফুলাহ (লেটিন)',
        'ff_Latn_BF' => 'ফুলাহ (লেটিন, বুৰকিনা ফাচো)',
        'ff_Latn_CM' => 'ফুলাহ (লেটিন, কেমেৰুণ)',
        'ff_Latn_GH' => 'ফুলাহ (লেটিন, ঘানা)',
        'ff_Latn_GM' => 'ফুলাহ (লেটিন, গাম্বিয়া)',
        'ff_Latn_GN' => 'ফুলাহ (লেটিন, গিনি)',
        'ff_Latn_GW' => 'ফুলাহ (লেটিন, গিনি-বিছাও)',
        'ff_Latn_LR' => 'ফুলাহ (লেটিন, লিবেৰিয়া)',
        'ff_Latn_MR' => 'ফুলাহ (লেটিন, মাউৰিটানিয়া)',
        'ff_Latn_NE' => 'ফুলাহ (লেটিন, নাইজাৰ)',
        'ff_Latn_NG' => 'ফুলাহ (লেটিন, নাইজেৰিয়া)',
        'ff_Latn_SL' => 'ফুলাহ (লেটিন, চিয়েৰা লিঅ’ন)',
        'ff_Latn_SN' => 'ফুলাহ (লেটিন, চেনেগাল)',
        'ff_MR' => 'ফুলাহ (মাউৰিটানিয়া)',
        'ff_SN' => 'ফুলাহ (চেনেগাল)',
        'fi' => 'ফিনিচ',
        'fi_FI' => 'ফিনিচ (ফিনলেণ্ড)',
        'fo' => 'ফাৰোইজ',
        'fo_DK' => 'ফাৰোইজ (ডেনমাৰ্ক)',
        'fo_FO' => 'ফাৰোইজ (ফাৰো দ্বীপপুঞ্জ)',
        'fr' => 'ফ্ৰেন্স',
        'fr_BE' => 'ফ্ৰেন্স (বেলজিয়াম)',
        'fr_BF' => 'ফ্ৰেন্স (বুৰকিনা ফাচো)',
        'fr_BI' => 'ফ্ৰেন্স (বুৰুণ্ডি)',
        'fr_BJ' => 'ফ্ৰেন্স (বেনিন)',
        'fr_BL' => 'ফ্ৰেন্স (ছেইণ্ট বাৰ্থলেমে)',
        'fr_CA' => 'ফ্ৰেন্স (কানাডা)',
        'fr_CD' => 'ফ্ৰেন্স (কঙ্গো - কিনচাছা)',
        'fr_CF' => 'ফ্ৰেন্স (মধ্য আফ্রিকান প্রজাতন্ত্র)',
        'fr_CG' => 'ফ্ৰেন্স (কঙ্গো - ব্রাজাভিল)',
        'fr_CH' => 'ফ্ৰেন্স (চুইজাৰলেণ্ড)',
        'fr_CI' => 'ফ্ৰেন্স (কোটে ডি আইভৰ)',
        'fr_CM' => 'ফ্ৰেন্স (কেমেৰুণ)',
        'fr_DJ' => 'ফ্ৰেন্স (জিবুটি)',
        'fr_DZ' => 'ফ্ৰেন্স (আলজেৰিয়া)',
        'fr_FR' => 'ফ্ৰেন্স (ফ্ৰান্স)',
        'fr_GA' => 'ফ্ৰেন্স (গেবন)',
        'fr_GF' => 'ফ্ৰেন্স (ফ্ৰান্স গয়ানা)',
        'fr_GN' => 'ফ্ৰেন্স (গিনি)',
        'fr_GP' => 'ফ্ৰেন্স (গুৱাডেলুপ)',
        'fr_GQ' => 'ফ্ৰেন্স (ইকুৱেটৰিয়েল গিনি)',
        'fr_HT' => 'ফ্ৰেন্স (হাইটি)',
        'fr_KM' => 'ফ্ৰেন্স (কোমোৰোজ)',
        'fr_LU' => 'ফ্ৰেন্স (লাক্সেমবাৰ্গ)',
        'fr_MA' => 'ফ্ৰেন্স (মৰক্কো)',
        'fr_MC' => 'ফ্ৰেন্স (মোনাকো)',
        'fr_MF' => 'ফ্ৰেন্স (ছেইণ্ট মাৰ্টিন)',
        'fr_MG' => 'ফ্ৰেন্স (মাদাগাস্কাৰ)',
        'fr_ML' => 'ফ্ৰেন্স (মালি)',
        'fr_MQ' => 'ফ্ৰেন্স (মাৰ্টিনিক)',
        'fr_MR' => 'ফ্ৰেন্স (মাউৰিটানিয়া)',
        'fr_MU' => 'ফ্ৰেন্স (মৰিছাছ)',
        'fr_NC' => 'ফ্ৰেন্স (নিউ কেলিডোনিয়া)',
        'fr_NE' => 'ফ্ৰেন্স (নাইজাৰ)',
        'fr_PF' => 'ফ্ৰেন্স (ফ্ৰান্স পোলেনচিয়া)',
        'fr_PM' => 'ফ্ৰেন্স (ছেইণ্ট পিয়েৰে আৰু মিকিউৱেলন)',
        'fr_RE' => 'ফ্ৰেন্স (ৰিইউনিয়ন)',
        'fr_RW' => 'ফ্ৰেন্স (ৰোৱাণ্ডা)',
        'fr_SC' => 'ফ্ৰেন্স (ছিচিলিছ)',
        'fr_SN' => 'ফ্ৰেন্স (চেনেগাল)',
        'fr_SY' => 'ফ্ৰেন্স (চিৰিয়া)',
        'fr_TD' => 'ফ্ৰেন্স (চাড)',
        'fr_TG' => 'ফ্ৰেন্স (টোগো)',
        'fr_TN' => 'ফ্ৰেন্স (টুনিচিয়া)',
        'fr_VU' => 'ফ্ৰেন্স (ভানাটু)',
        'fr_WF' => 'ফ্ৰেন্স (ৱালিছ আৰু ফুটুনা)',
        'fr_YT' => 'ফ্ৰেন্স (মায়োট্টে)',
        'fy' => 'ৱেষ্টাৰ্ণ ফ্ৰিছিয়ান',
        'fy_NL' => 'ৱেষ্টাৰ্ণ ফ্ৰিছিয়ান (নেডাৰলেণ্ড)',
        'ga' => 'আইৰিচ',
        'ga_GB' => 'আইৰিচ (সংযুক্ত ৰাজ্য)',
        'ga_IE' => 'আইৰিচ (আয়াৰলেণ্ড)',
        'gd' => 'স্কটিচ গেইলিক',
        'gd_GB' => 'স্কটিচ গেইলিক (সংযুক্ত ৰাজ্য)',
        'gl' => 'গেলিচিয়ান',
        'gl_ES' => 'গেলিচিয়ান (স্পেইন)',
        'gu' => 'গুজৰাটী',
        'gu_IN' => 'গুজৰাটী (ভাৰত)',
        'gv' => 'মেংক্স',
        'gv_IM' => 'মেংক্স (আইল অফ মেন)',
        'ha' => 'হাউছা',
        'ha_GH' => 'হাউছা (ঘানা)',
        'ha_NE' => 'হাউছা (নাইজাৰ)',
        'ha_NG' => 'হাউছা (নাইজেৰিয়া)',
        'he' => 'হিব্ৰু',
        'he_IL' => 'হিব্ৰু (ইজৰাইল)',
        'hi' => 'হিন্দী',
        'hi_IN' => 'হিন্দী (ভাৰত)',
        'hi_Latn' => 'হিন্দী (লেটিন)',
        'hi_Latn_IN' => 'হিন্দী (লেটিন, ভাৰত)',
        'hr' => 'ক্ৰোৱেচিয়ান',
        'hr_BA' => 'ক্ৰোৱেচিয়ান (ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'hr_HR' => 'ক্ৰোৱেচিয়ান (ক্ৰোৱেছিয়া)',
        'hu' => 'হাঙ্গেৰিয়ান',
        'hu_HU' => 'হাঙ্গেৰিয়ান (হাংগেৰী)',
        'hy' => 'আৰ্মেনীয়',
        'hy_AM' => 'আৰ্মেনীয় (আৰ্মেনিয়া)',
        'ia' => 'ইণ্টাৰলিংগুৱা',
        'ia_001' => 'ইণ্টাৰলিংগুৱা (বিশ্ব)',
        'id' => 'ইণ্ডোনেচিয়',
        'id_ID' => 'ইণ্ডোনেচিয় (ইণ্ডোনেচিয়া)',
        'ig' => 'ইগ্বো',
        'ig_NG' => 'ইগ্বো (নাইজেৰিয়া)',
        'ii' => 'ছিচুৱান ই',
        'ii_CN' => 'ছিচুৱান ই (চীন)',
        'is' => 'আইচলেণ্ডিক',
        'is_IS' => 'আইচলেণ্ডিক (আইচলেণ্ড)',
        'it' => 'ইটালিয়ান',
        'it_CH' => 'ইটালিয়ান (চুইজাৰলেণ্ড)',
        'it_IT' => 'ইটালিয়ান (ইটালি)',
        'it_SM' => 'ইটালিয়ান (চান মাৰিনো)',
        'it_VA' => 'ইটালিয়ান (ভেটিকান চিটি)',
        'ja' => 'জাপানী',
        'ja_JP' => 'জাপানী (জাপান)',
        'jv' => 'জাভানী',
        'jv_ID' => 'জাভানী (ইণ্ডোনেচিয়া)',
        'ka' => 'জৰ্জিয়ান',
        'ka_GE' => 'জৰ্জিয়ান (জৰ্জিয়া)',
        'ki' => 'কিকুয়ু',
        'ki_KE' => 'কিকুয়ু (কেনিয়া)',
        'kk' => 'কাজাখ',
        'kk_KZ' => 'কাজাখ (কাজাখাস্তান)',
        'kl' => 'কালালিছুট',
        'kl_GL' => 'কালালিছুট (গ্ৰীণলেণ্ড)',
        'km' => 'খমেৰ',
        'km_KH' => 'খমেৰ (কম্বোডিয়া)',
        'kn' => 'কানাড়া',
        'kn_IN' => 'কানাড়া (ভাৰত)',
        'ko' => 'কোৰিয়ান',
        'ko_KP' => 'কোৰিয়ান (উত্তৰ কোৰিয়া)',
        'ko_KR' => 'কোৰিয়ান (দক্ষিণ কোৰিয়া)',
        'ks' => 'কাশ্মিৰী',
        'ks_Arab' => 'কাশ্মিৰী (আৰবী)',
        'ks_Arab_IN' => 'কাশ্মিৰী (আৰবী, ভাৰত)',
        'ks_Deva' => 'কাশ্মিৰী (দেৱনাগৰী)',
        'ks_Deva_IN' => 'কাশ্মিৰী (দেৱনাগৰী, ভাৰত)',
        'ks_IN' => 'কাশ্মিৰী (ভাৰত)',
        'ku' => 'কুৰ্ডিচ',
        'ku_TR' => 'কুৰ্ডিচ (তুৰ্কিয়ে)',
        'kw' => 'কোৰ্নিচ',
        'kw_GB' => 'কোৰ্নিচ (সংযুক্ত ৰাজ্য)',
        'ky' => 'কিৰ্গিজ',
        'ky_KG' => 'কিৰ্গিজ (কিৰ্গিজস্তান)',
        'lb' => 'লাক্সেমবাৰ্গিচ',
        'lb_LU' => 'লাক্সেমবাৰ্গিচ (লাক্সেমবাৰ্গ)',
        'lg' => 'গান্দা',
        'lg_UG' => 'গান্দা (উগাণ্ডা)',
        'ln' => 'লিংগালা',
        'ln_AO' => 'লিংগালা (এংগোলা)',
        'ln_CD' => 'লিংগালা (কঙ্গো - কিনচাছা)',
        'ln_CF' => 'লিংগালা (মধ্য আফ্রিকান প্রজাতন্ত্র)',
        'ln_CG' => 'লিংগালা (কঙ্গো - ব্রাজাভিল)',
        'lo' => 'লাও',
        'lo_LA' => 'লাও (লাওচ)',
        'lt' => 'লিথুৱানিয়ান',
        'lt_LT' => 'লিথুৱানিয়ান (লিথুৱানিয়া)',
        'lu' => 'লুবা-কাটাংগা',
        'lu_CD' => 'লুবা-কাটাংগা (কঙ্গো - কিনচাছা)',
        'lv' => 'লাটভিয়ান',
        'lv_LV' => 'লাটভিয়ান (লাটভিয়া)',
        'mg' => 'মালাগাছী',
        'mg_MG' => 'মালাগাছী (মাদাগাস্কাৰ)',
        'mi' => 'মাওৰি',
        'mi_NZ' => 'মাওৰি (নিউজিলেণ্ড)',
        'mk' => 'মেচিডোনীয়',
        'mk_MK' => 'মেচিডোনীয় (উত্তৰ মেচিডোনীয়া)',
        'ml' => 'মালায়ালম',
        'ml_IN' => 'মালায়ালম (ভাৰত)',
        'mn' => 'মংগোলীয়',
        'mn_MN' => 'মংগোলীয় (মঙ্গোলিয়া)',
        'mr' => 'মাৰাঠী',
        'mr_IN' => 'মাৰাঠী (ভাৰত)',
        'ms' => 'মালয়',
        'ms_BN' => 'মালয় (ব্ৰুনেই)',
        'ms_ID' => 'মালয় (ইণ্ডোনেচিয়া)',
        'ms_MY' => 'মালয় (মালয়েচিয়া)',
        'ms_SG' => 'মালয় (ছিংগাপুৰ)',
        'mt' => 'মাল্টিজ',
        'mt_MT' => 'মাল্টিজ (মাল্টা)',
        'my' => 'বাৰ্মীজ',
        'my_MM' => 'বাৰ্মীজ (ম্যানমাৰ [বাৰ্মা])',
        'nb' => 'নৰৱেজিয়ান বোকমাল',
        'nb_NO' => 'নৰৱেজিয়ান বোকমাল (নৰৱে)',
        'nb_SJ' => 'নৰৱেজিয়ান বোকমাল (চাভালবাৰ্ড আৰু জন মেয়ন)',
        'nd' => 'উত্তৰ নিবেবেলে',
        'nd_ZW' => 'উত্তৰ নিবেবেলে (জিম্বাবৱে)',
        'ne' => 'নেপালী',
        'ne_IN' => 'নেপালী (ভাৰত)',
        'ne_NP' => 'নেপালী (নেপাল)',
        'nl' => 'ডাচ',
        'nl_AW' => 'ডাচ (আৰুবা)',
        'nl_BE' => 'ডাচ (বেলজিয়াম)',
        'nl_BQ' => 'ডাচ (কেৰিবিয়ান নেদাৰলেণ্ডছ)',
        'nl_CW' => 'ডাচ (কুৰাকাও)',
        'nl_NL' => 'ডাচ (নেডাৰলেণ্ড)',
        'nl_SR' => 'ডাচ (ছুৰিনাম)',
        'nl_SX' => 'ডাচ (চিণ্ট মাৰ্টেন)',
        'nn' => 'নৰৱেজিয়ান নায়নোৰ্স্ক',
        'nn_NO' => 'নৰৱেজিয়ান নায়নোৰ্স্ক (নৰৱে)',
        'no' => 'নৰৱেজিয়ান',
        'no_NO' => 'নৰৱেজিয়ান (নৰৱে)',
        'om' => 'ওৰোমো',
        'om_ET' => 'ওৰোমো (ইথিঅ’পিয়া)',
        'om_KE' => 'ওৰোমো (কেনিয়া)',
        'or' => 'ওড়িয়া',
        'or_IN' => 'ওড়িয়া (ভাৰত)',
        'os' => 'ওছেটিক',
        'os_GE' => 'ওছেটিক (জৰ্জিয়া)',
        'os_RU' => 'ওছেটিক (ৰাছিয়া)',
        'pa' => 'পাঞ্জাবী',
        'pa_Arab' => 'পাঞ্জাবী (আৰবী)',
        'pa_Arab_PK' => 'পাঞ্জাবী (আৰবী, পাকিস্তান)',
        'pa_Guru' => 'পাঞ্জাবী (গুৰুমুখী)',
        'pa_Guru_IN' => 'পাঞ্জাবী (গুৰুমুখী, ভাৰত)',
        'pa_IN' => 'পাঞ্জাবী (ভাৰত)',
        'pa_PK' => 'পাঞ্জাবী (পাকিস্তান)',
        'pl' => 'প’লিচ',
        'pl_PL' => 'প’লিচ (পোলেণ্ড)',
        'ps' => 'পুস্ত',
        'ps_AF' => 'পুস্ত (আফগানিস্তান)',
        'ps_PK' => 'পুস্ত (পাকিস্তান)',
        'pt' => 'পৰ্তুগীজ',
        'pt_AO' => 'পৰ্তুগীজ (এংগোলা)',
        'pt_BR' => 'পৰ্তুগীজ (ব্ৰাজিল)',
        'pt_CH' => 'পৰ্তুগীজ (চুইজাৰলেণ্ড)',
        'pt_CV' => 'পৰ্তুগীজ (কেপ ভার্দে)',
        'pt_GQ' => 'পৰ্তুগীজ (ইকুৱেটৰিয়েল গিনি)',
        'pt_GW' => 'পৰ্তুগীজ (গিনি-বিছাও)',
        'pt_LU' => 'পৰ্তুগীজ (লাক্সেমবাৰ্গ)',
        'pt_MO' => 'পৰ্তুগীজ (মাকাও এছ. এ. আৰ. চীন)',
        'pt_MZ' => 'পৰ্তুগীজ (ম’জামবিক)',
        'pt_PT' => 'পৰ্তুগীজ (পৰ্তুগাল)',
        'pt_ST' => 'পৰ্তুগীজ (চাও টোমে আৰু প্ৰিনচিপে)',
        'pt_TL' => 'পৰ্তুগীজ (টিমোৰ-লেচটে)',
        'qu' => 'কুৱেচুৱা',
        'qu_BO' => 'কুৱেচুৱা (বলিভিয়া)',
        'qu_EC' => 'কুৱেচুৱা (ইকুৱেডৰ)',
        'qu_PE' => 'কুৱেচুৱা (পেৰু)',
        'rm' => 'ৰোমানচ',
        'rm_CH' => 'ৰোমানচ (চুইজাৰলেণ্ড)',
        'rn' => 'ৰুন্দি',
        'rn_BI' => 'ৰুন্দি (বুৰুণ্ডি)',
        'ro' => 'ৰোমানীয়',
        'ro_MD' => 'ৰোমানীয় (মোলডোভা)',
        'ro_RO' => 'ৰোমানীয় (ৰোমানিয়া)',
        'ru' => 'ৰাছিয়ান',
        'ru_BY' => 'ৰাছিয়ান (বেলাৰুছ)',
        'ru_KG' => 'ৰাছিয়ান (কিৰ্গিজস্তান)',
        'ru_KZ' => 'ৰাছিয়ান (কাজাখাস্তান)',
        'ru_MD' => 'ৰাছিয়ান (মোলডোভা)',
        'ru_RU' => 'ৰাছিয়ান (ৰাছিয়া)',
        'ru_UA' => 'ৰাছিয়ান (ইউক্ৰেইন)',
        'rw' => 'কিনয়াৰোৱাণ্ডা',
        'rw_RW' => 'কিনয়াৰোৱাণ্ডা (ৰোৱাণ্ডা)',
        'sa' => 'সংস্কৃত',
        'sa_IN' => 'সংস্কৃত (ভাৰত)',
        'sc' => 'ছাৰ্ডিনিয়ান',
        'sc_IT' => 'ছাৰ্ডিনিয়ান (ইটালি)',
        'sd' => 'সিন্ধী',
        'sd_Arab' => 'সিন্ধী (আৰবী)',
        'sd_Arab_PK' => 'সিন্ধী (আৰবী, পাকিস্তান)',
        'sd_Deva' => 'সিন্ধী (দেৱনাগৰী)',
        'sd_Deva_IN' => 'সিন্ধী (দেৱনাগৰী, ভাৰত)',
        'sd_IN' => 'সিন্ধী (ভাৰত)',
        'sd_PK' => 'সিন্ধী (পাকিস্তান)',
        'se' => 'উদীচ্য ছামি',
        'se_FI' => 'উদীচ্য ছামি (ফিনলেণ্ড)',
        'se_NO' => 'উদীচ্য ছামি (নৰৱে)',
        'se_SE' => 'উদীচ্য ছামি (চুইডেন)',
        'sg' => 'ছাঙ্গো',
        'sg_CF' => 'ছাঙ্গো (মধ্য আফ্রিকান প্রজাতন্ত্র)',
        'si' => 'সিংহলা',
        'si_LK' => 'সিংহলা (শ্রীলংকা)',
        'sk' => 'শ্লোভাক',
        'sk_SK' => 'শ্লোভাক (শ্লোভাকিয়া)',
        'sl' => 'শ্লোভেনিয়ান',
        'sl_SI' => 'শ্লোভেনিয়ান (শ্লোভেনিয়া)',
        'sn' => 'চোনা',
        'sn_ZW' => 'চোনা (জিম্বাবৱে)',
        'so' => 'ছোমালি',
        'so_DJ' => 'ছোমালি (জিবুটি)',
        'so_ET' => 'ছোমালি (ইথিঅ’পিয়া)',
        'so_KE' => 'ছোমালি (কেনিয়া)',
        'so_SO' => 'ছোমালি (চোমালিয়া)',
        'sq' => 'আলবেনীয়',
        'sq_AL' => 'আলবেনীয় (আলবেনিয়া)',
        'sq_MK' => 'আলবেনীয় (উত্তৰ মেচিডোনীয়া)',
        'sr' => 'ছাৰ্বিয়ান',
        'sr_BA' => 'ছাৰ্বিয়ান (ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'sr_Cyrl' => 'ছাৰ্বিয়ান (চিৰিলিক)',
        'sr_Cyrl_BA' => 'ছাৰ্বিয়ান (চিৰিলিক, ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'sr_Cyrl_ME' => 'ছাৰ্বিয়ান (চিৰিলিক, মণ্টেনেগ্ৰু)',
        'sr_Cyrl_RS' => 'ছাৰ্বিয়ান (চিৰিলিক, ছাৰ্বিয়া)',
        'sr_Latn' => 'ছাৰ্বিয়ান (লেটিন)',
        'sr_Latn_BA' => 'ছাৰ্বিয়ান (লেটিন, ব’ছনিয়া আৰু হাৰ্জেগ’ভিনা)',
        'sr_Latn_ME' => 'ছাৰ্বিয়ান (লেটিন, মণ্টেনেগ্ৰু)',
        'sr_Latn_RS' => 'ছাৰ্বিয়ান (লেটিন, ছাৰ্বিয়া)',
        'sr_ME' => 'ছাৰ্বিয়ান (মণ্টেনেগ্ৰু)',
        'sr_RS' => 'ছাৰ্বিয়ান (ছাৰ্বিয়া)',
        'su' => 'ছুণ্ডানীজ',
        'su_ID' => 'ছুণ্ডানীজ (ইণ্ডোনেচিয়া)',
        'su_Latn' => 'ছুণ্ডানীজ (লেটিন)',
        'su_Latn_ID' => 'ছুণ্ডানীজ (লেটিন, ইণ্ডোনেচিয়া)',
        'sv' => 'ছুইডিচ',
        'sv_AX' => 'ছুইডিচ (আলণ্ড দ্বীপপুঞ্জ)',
        'sv_FI' => 'ছুইডিচ (ফিনলেণ্ড)',
        'sv_SE' => 'ছুইডিচ (চুইডেন)',
        'sw' => 'স্বাহিলি',
        'sw_CD' => 'স্বাহিলি (কঙ্গো - কিনচাছা)',
        'sw_KE' => 'স্বাহিলি (কেনিয়া)',
        'sw_TZ' => 'স্বাহিলি (তাঞ্জানিয়া)',
        'sw_UG' => 'স্বাহিলি (উগাণ্ডা)',
        'ta' => 'তামিল',
        'ta_IN' => 'তামিল (ভাৰত)',
        'ta_LK' => 'তামিল (শ্রীলংকা)',
        'ta_MY' => 'তামিল (মালয়েচিয়া)',
        'ta_SG' => 'তামিল (ছিংগাপুৰ)',
        'te' => 'তেলুগু',
        'te_IN' => 'তেলুগু (ভাৰত)',
        'tg' => 'তাজিক',
        'tg_TJ' => 'তাজিক (তাজিকিস্তান)',
        'th' => 'থাই',
        'th_TH' => 'থাই (থাইলেণ্ড)',
        'ti' => 'টিগৰিনিয়া',
        'ti_ER' => 'টিগৰিনিয়া (এৰিত্ৰিয়া)',
        'ti_ET' => 'টিগৰিনিয়া (ইথিঅ’পিয়া)',
        'tk' => 'তুৰ্কমেন',
        'tk_TM' => 'তুৰ্কমেন (তুৰ্কমেনিস্তান)',
        'to' => 'টোঙ্গান',
        'to_TO' => 'টোঙ্গান (টংগা)',
        'tr' => 'তুৰ্কী',
        'tr_CY' => 'তুৰ্কী (চাইপ্ৰাছ)',
        'tr_TR' => 'তুৰ্কী (তুৰ্কিয়ে)',
        'tt' => 'তাতাৰ',
        'tt_RU' => 'তাতাৰ (ৰাছিয়া)',
        'ug' => 'উইঘুৰ',
        'ug_CN' => 'উইঘুৰ (চীন)',
        'uk' => 'ইউক্ৰেইনীয়',
        'uk_UA' => 'ইউক্ৰেইনীয় (ইউক্ৰেইন)',
        'ur' => 'উৰ্দু',
        'ur_IN' => 'উৰ্দু (ভাৰত)',
        'ur_PK' => 'উৰ্দু (পাকিস্তান)',
        'uz' => 'উজবেক',
        'uz_AF' => 'উজবেক (আফগানিস্তান)',
        'uz_Arab' => 'উজবেক (আৰবী)',
        'uz_Arab_AF' => 'উজবেক (আৰবী, আফগানিস্তান)',
        'uz_Cyrl' => 'উজবেক (চিৰিলিক)',
        'uz_Cyrl_UZ' => 'উজবেক (চিৰিলিক, উজবেকিস্তান)',
        'uz_Latn' => 'উজবেক (লেটিন)',
        'uz_Latn_UZ' => 'উজবেক (লেটিন, উজবেকিস্তান)',
        'uz_UZ' => 'উজবেক (উজবেকিস্তান)',
        'vi' => 'ভিয়েটনামী',
        'vi_VN' => 'ভিয়েটনামী (ভিয়েটনাম)',
        'wo' => 'ৱোলাফ',
        'wo_SN' => 'ৱোলাফ (চেনেগাল)',
        'xh' => 'হোছা',
        'xh_ZA' => 'হোছা (দক্ষিণ আফ্রিকা)',
        'yi' => 'ইদ্দিছ',
        'yi_001' => 'ইদ্দিছ (বিশ্ব)',
        'yo' => 'ইউৰুবা',
        'yo_BJ' => 'ইউৰুবা (বেনিন)',
        'yo_NG' => 'ইউৰুবা (নাইজেৰিয়া)',
        'zh' => 'চীনা',
        'zh_CN' => 'চীনা (চীন)',
        'zh_HK' => 'চীনা (হং কং এছ. এ. আৰ. চীন)',
        'zh_Hans' => 'চীনা (সৰলীকৃত)',
        'zh_Hans_CN' => 'চীনা (সৰলীকৃত, চীন)',
        'zh_Hans_HK' => 'চীনা (সৰলীকৃত, হং কং এছ. এ. আৰ. চীন)',
        'zh_Hans_MO' => 'চীনা (সৰলীকৃত, মাকাও এছ. এ. আৰ. চীন)',
        'zh_Hans_SG' => 'চীনা (সৰলীকৃত, ছিংগাপুৰ)',
        'zh_Hant' => 'চীনা (পৰম্পৰাগত)',
        'zh_Hant_HK' => 'চীনা (পৰম্পৰাগত, হং কং এছ. এ. আৰ. চীন)',
        'zh_Hant_MO' => 'চীনা (পৰম্পৰাগত, মাকাও এছ. এ. আৰ. চীন)',
        'zh_Hant_TW' => 'চীনা (পৰম্পৰাগত, টাইৱান)',
        'zh_MO' => 'চীনা (মাকাও এছ. এ. আৰ. চীন)',
        'zh_SG' => 'চীনা (ছিংগাপুৰ)',
        'zh_TW' => 'চীনা (টাইৱান)',
        'zu' => 'ঝুলু',
        'zu_ZA' => 'ঝুলু (দক্ষিণ আফ্রিকা)',
    ],
];
